@@ -2,8 +2,9 @@ import gtk
 import hildon
 from ctypes import *
 from pygobject import *
+from org.maemo.hermes.gui.searchablelist import SearchableList
 
-class MapContact(hildon.PannableArea):
+class MapContact(SearchableList):
     """Widget which shows a list of friends from various feeds and allows
        the mapping to a particular contact.
        
@@ -15,7 +16,7 @@ class MapContact(hildon.PannableArea):
     def __init__(self, friends, contact):
         """Constructor. Passed a list of `friends' and the contact we're mapping."""
         
-        hildon.PannableArea.__init__(self)
+        SearchableList.__init__(self, 1)
         self.friends = friends
         self.contact = contact
         self.treestore = gtk.ListStore(gtk.gdk.Pixbuf, str, gtk.gdk.Pixbuf, gobject.TYPE_PYOBJECT)
@@ -73,7 +74,6 @@ class MapContact(hildon.PannableArea):
             self.treeview.get_selection().unselect_all()
           
         self.add(self.treeview)
-        self.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
 
       
     # -----------------------------------------------------------------------
